#include "Effect.h"
#include "effect_big_clock.h"
#include "fonts.h"
#include "ntp.h"
#include "settings.h"

void BigClockEffect::loop(uint16_t ms) {
    window->clear();
    uint8_t h = ntpClient.getHours();
    window->drawChar(&font_numbers3x5_blocky, 6<<8, 2<<8, '0' + (h / 10), &_color_font);
    window->drawChar(&font_numbers3x5_blocky, 11<<8, 2<<8, '0' + (h % 10), &_color_font);

    uint8_t m = ntpClient.getMinutes();
    window->drawChar(&font_numbers3x5_blocky, 6<<8, 9<<8, '0' + (m / 10), &_color_font);
    window->drawChar(&font_numbers3x5_blocky, 11<<8, 9<<8, '0' + (m % 10), &_color_font);

    uint8_t s = ntpClient.getSeconds();
    if (s & 1) {
    	window->setPixel(3, 10, &_color_font);
    	window->setPixel(3, 12, &_color_font);
    }

    _draw_seconds();
}

void BigClockEffect::_draw_seconds() {
	uint8_t seconds = ntpClient.getSeconds();
	for (int i=1; i<=seconds; i++) {
		_draw_border_pixel(i<<8, (i%5==0) ? &_color_seconds_light : &_color_seconds_dark);
	}

	uint16_t millis = ntpClient.getEpochMillis() % 1000;
	accum88 pos = (seconds<<8) + ((settings.effects.big_clock.spacing-1)<<8) * (1000 - millis) / 1000 + (1<<8);
    uint8_t sec = seconds + 1;
    while (pos < (60<<8)) {
		_draw_border_pixel(pos, sec%5==0 ? &_color_seconds_moving_light : &_color_seconds_moving_dark);
        pos += settings.effects.big_clock.spacing<<8;
        sec++;
	}
}

void BigClockEffect::_draw_border_pixel(accum88 i, CRGB* color) {
	accum88 x, y;
	if (i<(8<<8)) {
		x = i + (7<<8);
		y = 0;
	} else if (i<(23<<8)) {
		x = 15<<8;
		y = i - (8<<8);
	} else if (i<(38<<8)) {
		x = (38<<8) - i;
		y = 15<<8;
	} else if (i<(53<<8)) {
		x = 0;
		y = (53<<8) - i;
	} else if (i<=(60<<8)) {
		x = i - (53<<8);
		y = 0;
	} else {
		return;
	}
	window->setSubPixel(x, y, color);
}
